"use strict";

/* exported logger */

var logger = require('../../logger');

function UserPreferences(javaObject) {
  if (javaObject !== undefined) {
    this.setProjectUpload(javaObject["project-upload"]);
    this.setElementAnnotators(javaObject["element-annotators"]);
    this.setElementRequiredAnnotations(javaObject["element-required-annotations"]);
    this.setElementValidAnnotations(javaObject["element-valid-annotations"]);
  } else {
    this._projectUpload = {};
    this._elementAnnotators = {};
    this._elementRequiredAnnotations = {};
    this._elementValidAnnotations = {};
  }
}

UserPreferences.prototype.setProjectUpload = function (projectUpload) {
  this._projectUpload = {
    autoResize: projectUpload["auto-resize"],
    validateMiriam: projectUpload["validate-miriam"],
    annotateModel: projectUpload["annotate-model"],
    cacheData: projectUpload["cache-data"],
    semanticZooming: projectUpload["semantic-zooming"],
    sbgn: projectUpload["sbgn"]
  };
};
UserPreferences.prototype.getProjectUpload = function () {
  return this._projectUpload;
};
UserPreferences.prototype.setElementAnnotators = function (elementAnnotators) {
  this._elementAnnotators = elementAnnotators;
};
UserPreferences.prototype.getElementAnnotators = function (className) {
  return this._elementAnnotators[className];
};
UserPreferences.prototype.setElementRequiredAnnotations = function (elementRequiredAnnotations) {
  this._elementRequiredAnnotations = {};
  for (var key in elementRequiredAnnotations) {
    if (elementRequiredAnnotations.hasOwnProperty(key)) {
      var data = elementRequiredAnnotations[key];
      this._elementRequiredAnnotations[key] = {
        requiredAtLeastOnce: data["require-at-least-one"],
        list: data["annotation-list"]
      };
    }
  }
};
UserPreferences.prototype.getElementRequiredAnnotations = function (className) {
  return this._elementRequiredAnnotations[className];
};
UserPreferences.prototype.setElementValidAnnotations = function (elementValidAnnotations) {
  this._elementValidAnnotations = elementValidAnnotations;
};
UserPreferences.prototype.getElementValidAnnotations = function (className) {
  return this._elementValidAnnotations[className];
};

UserPreferences.prototype.toExport = function (className) {
  return {
    "project-upload": {
      "auto-resize": this._projectUpload.autoResize,
      "validate-miriam": this._projectUpload.validateMiriam,
      "annotate-model": this._projectUpload.annotateModel,
      "cache-data": this._projectUpload.cacheData,
      "sbgn": this._projectUpload.sbgn,
      "semantic-zooming": this._projectUpload.semanticZooming
    }
  };
};

module.exports = UserPreferences;
